@@ -13,7 +13,7 @@
 ##############################################################################
 """A WSGI Application wrapper for zope
 
-$Id: __init__.py 119207 2010-12-28 19:49:21Z menesis $
+$Id: __init__.py 124018 2012-01-10 23:06:01Z jim $
 """
 import os
 import sys
@@ -65,6 +65,8 @@ class WSGIPublisherApplication(object):
         else:
             message = logging_info.getLogMessage()
         environ['wsgi.logging_info'] = message
+        if 'REMOTE_USER' not in environ:
+            environ['REMOTE_USER'] = message
 
         # Start the WSGI server response
         start_response(response.getStatusString(), response.getHeaders())
