@@ -13,9 +13,11 @@
 ##############################################################################
 """An application factory for Paste
 
-$Id: paste.py 119207 2010-12-28 19:49:21Z menesis $
+$Id: paste.py 124089 2012-01-19 15:03:08Z jim $
 """
 from zope.app.wsgi import getWSGIApplication
+import zope.event
+import zope.processlifetime
 
 
 def asbool(obj):
@@ -30,4 +32,6 @@ def asbool(obj):
 
 def ZopeApplication(global_config, config_file, handle_errors=True, **options):
     handle_errors = asbool(handle_errors)
-    return getWSGIApplication(config_file, handle_errors=handle_errors)
+    app = getWSGIApplication(config_file, handle_errors=handle_errors)
+    zope.event.notify(zope.processlifetime.ProcessStarting())
+    return app
