@@ -26,6 +26,42 @@ import zope.event
 def cleanEvents(s):
     zope.event.subscribers.pop()
 
+def creating_app_w_paste_emits_ProcessStarting_event():
+    """
+    >>> import zope.event
+    >>> events = []
+    >>> subscriber = events.append
+    >>> zope.event.subscribers.append(subscriber)
+
+    >>> import os, tempfile
+    >>> temp_dir = tempfile.mkdtemp()
+    >>> sitezcml = os.path.join(temp_dir, 'site.zcml')
+    >>> open(sitezcml, 'w').write('<configure />')
+    >>> zopeconf = os.path.join(temp_dir, 'zope.conf')
+    >>> open(zopeconf, 'w').write('''
+    ... site-definition %s
+    ...
+    ... <zodb>
+    ...   <mappingstorage />
+    ... </zodb>
+    ...
+    ... <eventlog>
+    ...   <logfile>
+    ...     path STDOUT
+    ...   </logfile>
+    ... </eventlog>
+    ... ''' % sitezcml)
+
+    >>> import zope.app.wsgi.paste, zope.processlifetime
+    >>> app = zope.app.wsgi.paste.ZopeApplication(
+    ...     {}, zopeconf, handle_errors=False)
+
+    >>> len([e for e in events
+    ...     if isinstance(e, zope.processlifetime.ProcessStarting)]) == 1
+    True
+
+    >>> zope.event.subscribers.remove(subscriber)
+    """
 
 def test_suite():
 
@@ -36,6 +72,8 @@ def test_suite():
         ])
     filereturns_suite = doctest.DocFileSuite('filereturns.txt')
     filereturns_suite.layer = BrowserLayer(zope.app.wsgi)
+    dt_suite = doctest.DocTestSuite()
+    dt_suite.layer = BrowserLayer(zope.app.wsgi)
 
     readme_test = doctest.DocFileSuite(
             'README.txt',
@@ -56,4 +94,6 @@ def test_suite():
     testlayer_suite.layer = SillyMiddleWareBrowserLayer(zope.app.wsgi)
 
     return unittest.TestSuite((
-        filereturns_suite, readme_test, doctest_suite, testlayer_suite))
+        filereturns_suite, readme_test, doctest_suite, testlayer_suite,
+        dt_suite,
+        ))
